pub struct SystemOneService {
pub state: AppState,
pub auth: AuthConfig,
pub limits: RequestLimits,
}Expand description
gRPC service implementation of the openkind.SystemOne service contract.
Fields
state: AppStateShared application state containing the model registry.
auth: AuthConfigAuthentication configuration.
limits: RequestLimitsTransport budgets, optionally shared with the HTTP listener.
Implementations
Sourceimpl SystemOneService
impl SystemOneService
Sourcepub fn new(registry: EngineRegistry) -> Self
pub fn new(registry: EngineRegistry) -> Self
Construct a new SystemOneService backed by the specified engine registry and default auth.
Sourcepub fn with_auth(registry: EngineRegistry, auth: AuthConfig) -> Self
pub fn with_auth(registry: EngineRegistry, auth: AuthConfig) -> Self
Construct a new SystemOneService backed by the specified engine registry and auth configuration.
Sourcepub fn with_auth_and_limits(
registry: EngineRegistry,
auth: AuthConfig,
limits: RequestLimits,
) -> Self
pub fn with_auth_and_limits( registry: EngineRegistry, auth: AuthConfig, limits: RequestLimits, ) -> Self
Construct the service with explicit, potentially shared transport budgets.